@@ -1,5 +1,5 @@
 "plot.frailtyPenal" <- "plot.nestedPenal" <- "plot.additivePenal" <-
-function (x, type.plot="hazard", conf.bands=TRUE, ...) 
+function (x, type.plot="hazard", conf.bands=TRUE, pos.legend="topright", cex.legend=0.7, main, ...) 
 {
   
    plot.type <- charmatch(type.plot, c("hazard", "survival"), 
@@ -8,6 +8,9 @@ function (x, type.plot="hazard", conf.bands=TRUE, ...)
         stop("estimator must be hazard or survival")
     }
 
+  if(missing(main))
+   main<-""
+
   if(plot.type==1)
    {
 
@@ -15,27 +18,27 @@ function (x, type.plot="hazard", conf.bands=TRUE, ...)
       {  
         if (conf.bands)
             matplot(x$x1, x$lam, col=1, type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", main=main, ...)
         else
             plot(x$x1, x$lam[,1], col=1, type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Hazard function", ...)
+                ylab="Hazard function", main=main, ...)
       }
     else
       {
        if (conf.bands)
          {
            matplot(x$x1, x$lam, col=1, type="l", lty=c(1,2,2), xlab="Time",
-                  ylab="Hazard function", ...)
+                  ylab="Hazard function", main=main, ...)
            matlines(x$x2, x$lam2, col=2, type="l", lty=c(1,2,2),...)
          }
        else
          {
            plot(x$x1, x$lam[,1], col=1, type="l", lty=c(1,2,2), xlab="Time",
-                  ylab="Hazard function", ...)
+                  ylab="Hazard function", main=main, ...)
            lines(x$x2, x$lam2[,1], col=2, type="l", lty=c(1,2,2),...)
          }
   
-      legend("topleft", c("strata=1", "strata=2"), lty=2, col=c(1,2))
+      legend(pos.legend, c("strata=1", "strata=2"), lty=2, col=c(1,2), cex=cex.legend, ...)
 
       } 
    }        
@@ -47,27 +50,27 @@ function (x, type.plot="hazard", conf.bands=TRUE, ...)
       {  
         if (conf.bands)
            matplot(x$x1, x$surv, col=1, type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ...)
+                ylab="Baseline survival function", main=main, ...)
         else        
            plot(x$x1, x$surv[,1], col=1, type="l", lty=c(1,2,2), xlab="Time",
-                ylab="Baseline survival function", ...)
+                ylab="Baseline survival function", main=main, ...)
       }
     else
       {
         if (conf.bands)
           {
             matplot(x$x1, x$surv, col=1, type="l", lty=c(1,2,2), xlab="Time",
-                   ylab="Baseline survival function", ...)
+                   ylab="Baseline survival function", main=main, ...)
             matlines(x$x2, x$surv2, col=2, type="l", lty=c(1,2,2), ...)
           }
         else 
           {
             plot(x$x1, x$surv[,1], col=1, type="l", lty=c(1,2,2), xlab="Time",
-                   ylab="Baseline survival function", ...)
+                   ylab="Baseline survival function", main=main, ...)
             lines(x$x2, x$surv2[,1], col=2, type="l", lty=c(1,2,2), ...)
           }
         
-        legend("topleft", c("strata=1", "strata=2"), lty=2, col=c(1,2))
+        legend(pos.legend, c("strata=1", "strata=2"), lty=2, col=c(1,2), cex=cex.legend, ...)
 
       } 
    }        
